==> message-facade-2.0.2-20211010.135344-95-sources.jar: com/bizvane/messagefacade/models/vo/AjhOrderMessageVO.java <==
package com.bizvane.messagefacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

public class AjhOrderMessageVO implements Serializable {
    /**
     *
     */
    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "订单编号", name = "orderNo", required = false, example = "")
    private String orderNo;

    @ApiModelProperty(value = "下单时间", name = "orderTime", required = false, example = "")
    private String orderTime;

    @ApiModelProperty(value = "发货时间", name = "deliveryTime", required = false, example = "")
    private String deliveryTime;

    @ApiModelProperty(value = "收获地址", name = "address", required = false, example = "")
    private String address;

    @ApiModelProperty(value = "安装师傅电话", name = "masterPhone", required = false, example = "")
    private String masterPhone;

    @ApiModelProperty(value = "安装师傅姓名", name = "masterName", required = false, example = "")
    private String masterName;

    @ApiModelProperty(value = "订单类型", name = "orderType", required = false, example = "")
    private String orderType;

    @ApiModelProperty(value = "预约时间", name = "subscribeTime", required = false, example = "")
    private String subscribeTime;

    @ApiModelProperty(value = "配送地址", name = "deliveryAddress", required = false, example = "")
    private String deliveryAddress;

    @ApiModelProperty(value = "售后状态", name = "afterMarketStatus", required = false, example = "")
    private String afterMarketStatus;

    @ApiModelProperty(value = "售后详情", name = "afterMarketDetail", required = false, example = "")
    private String afterMarketDetail;


    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getOrderTime() {
        return orderTime;
    }

    public void setOrderTime(String orderTime) {
        this.orderTime = orderTime;
    }

    public String getDeliveryTime() {
        return deliveryTime;
    }

    public void setDeliveryTime(String deliveryTime) {
        this.deliveryTime = deliveryTime;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getMasterPhone() {
        return masterPhone;
    }

    public void setMasterPhone(String masterPhone) {
        this.masterPhone = masterPhone;
    }

    public String getMasterName() {
        return masterName;
    }

    public void setMasterName(String masterName) {
        this.masterName = masterName;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getSubscribeTime() {
        return subscribeTime;
    }

    public void setSubscribeTime(String subscribeTime) {
        this.subscribeTime = subscribeTime;
    }

    public String getDeliveryAddress() {
        return deliveryAddress;
    }

    public void setDeliveryAddress(String deliveryAddress) {
        this.deliveryAddress = deliveryAddress;
    }

    public String getAfterMarketStatus() {
        return afterMarketStatus;
    }

    public void setAfterMarketStatus(String afterMarketStatus) {
        this.afterMarketStatus = afterMarketStatus;
    }

    public String getAfterMarketDetail() {
        return afterMarketDetail;
    }

    public void setAfterMarketDetail(String afterMarketDetail) {
        this.afterMarketDetail = afterMarketDetail;
    }
}

==> message-facade-2.0.2-20211020.101656-105-sources.jar: com/bizvane/messagefacade/models/vo/AjhOrderMessageVO.java <==
package com.bizvane.messagefacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

public class AjhOrderMessageVO implements Serializable {
    /**
     *
     */
    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "订单编号", name = "orderNo", required = false, example = "")
    private String orderNo;

    @ApiModelProperty(value = "下单时间", name = "orderTime", required = false, example = "")
    private String orderTime;

    @ApiModelProperty(value = "发货时间", name = "deliveryTime", required = false, example = "")
    private String deliveryTime;

    @ApiModelProperty(value = "收获地址", name = "address", required = false, example = "")
    private String address;

    @ApiModelProperty(value = "安装师傅电话", name = "masterPhone", required = false, example = "")
    private String masterPhone;

    @ApiModelProperty(value = "安装师傅姓名", name = "masterName", required = false, example = "")
    private String masterName;

    @ApiModelProperty(value = "订单类型", name = "orderType", required = false, example = "")
    private String orderType;

    @ApiModelProperty(value = "预约时间", name = "subscribeTime", required = false, example = "")
    private String subscribeTime;

    @ApiModelProperty(value = "配送地址", name = "deliveryAddress", required = false, example = "")
    private String deliveryAddress;

    @ApiModelProperty(value = "售后状态", name = "afterMarketStatus", required = false, example = "")
    private String afterMarketStatus;

    @ApiModelProperty(value = "售后详情", name = "afterMarketDetail", required = false, example = "")
    private String afterMarketDetail;

    @ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
    private Long sysBrandId;

    @ApiModelProperty(value = "企业id", name = "sysCompanyId")
    private Long sysCompanyId;

    @ApiModelProperty(value = "会员手机号", name = "memberPhone", required = false, example = "")
    private String memberPhone;

    @ApiModelProperty(value = "会员编号", name = "memberCode", required = false, example = "")
    private String memberCode;


    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getOrderTime() {
        return orderTime;
    }

    public void setOrderTime(String orderTime) {
        this.orderTime = orderTime;
    }

    public String getDeliveryTime() {
        return deliveryTime;
    }

    public void setDeliveryTime(String deliveryTime) {
        this.deliveryTime = deliveryTime;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getMasterPhone() {
        return masterPhone;
    }

    public void setMasterPhone(String masterPhone) {
        this.masterPhone = masterPhone;
    }

    public String getMasterName() {
        return masterName;
    }

    public void setMasterName(String masterName) {
        this.masterName = masterName;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getSubscribeTime() {
        return subscribeTime;
    }

    public void setSubscribeTime(String subscribeTime) {
        this.subscribeTime = subscribeTime;
    }

    public String getDeliveryAddress() {
        return deliveryAddress;
    }

    public void setDeliveryAddress(String deliveryAddress) {
        this.deliveryAddress = deliveryAddress;
    }

    public String getAfterMarketStatus() {
        return afterMarketStatus;
    }

    public void setAfterMarketStatus(String afterMarketStatus) {
        this.afterMarketStatus = afterMarketStatus;
    }

    public String getAfterMarketDetail() {
        return afterMarketDetail;
    }

    public void setAfterMarketDetail(String afterMarketDetail) {
        this.afterMarketDetail = afterMarketDetail;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public String getMemberPhone() {
        return memberPhone;
    }

    public void setMemberPhone(String memberPhone) {
        this.memberPhone = memberPhone;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }
}
